pub fn sanitycheck_input_layers_and_claims<F: Field>(
input_layer_claims: &[Claim<F>],
circuit_description: &GKRCircuitDescription<F>,
)Expand description
Prints all claims on input layers, aggregated by input layer, along with the number of variables in each input layer where a claim is made.
Purely for sanitycheck against input layers and ensuring that # claims roughly matches expected # claims.